@@ -46,7 +46,7 @@ int main( int argc, char ** argv )
 
     Akonadi::AkonadiServer::instance(); // trigger singleton creation
 
-    if ( !QDBusConnection::sessionBus().registerService( QLatin1String("org.kde.Akonadi") ) ) {
+    if ( !QDBusConnection::sessionBus().registerService( QLatin1String("org.freedesktop.Akonadi") ) ) {
       qDebug( "Unable to connect to dbus service: %s", qPrintable( QDBusConnection::sessionBus().lastError().message() ) );
       return 1;
     }
