@@ -313,7 +313,7 @@ bool DataStore::appendItemFlags( const PimItem &item, const QList<QByteArray> &f
                                  bool checkIfExists, const Location &loc )
 {
   Flag::List list;
-  foreach ( const QByteArray f, flags ) {
+  foreach ( const QByteArray &f, flags ) {
     Flag flag = Flag::retrieveByName( QString::fromUtf8( f ) );
     if ( !flag.isValid() ) {
       flag = Flag( QString::fromUtf8( f ) );
@@ -425,7 +425,7 @@ bool DataStore::appendMimeTypeForLocation( qint64 locationId, const QStringList
     return false;
   QStringList missingMimeTypes = mimeTypes;
 
-  foreach ( const MimeType mt, qb.result() ) {
+  foreach ( const MimeType &mt, qb.result() ) {
     // unique index on n:m relation prevents duplicates, ie. this will fail
     // if this mimetype is already set
     if ( !Location::addMimeType( locationId, mt.id() ) )
@@ -434,7 +434,7 @@ bool DataStore::appendMimeTypeForLocation( qint64 locationId, const QStringList
   }
 
   // the MIME type doesn't exist, so we have to add it to the db
-  foreach ( const QString mtName, missingMimeTypes ) {
+  foreach ( const QString &mtName, missingMimeTypes ) {
     qint64 mimeTypeId;
     if ( !appendMimeType( mtName, &mimeTypeId ) )
       return false;
@@ -636,7 +636,7 @@ bool DataStore::cleanupPimItems( const Location &location )
   return ok;
 }
 
-void Akonadi::DataStore::retrieveDataFromResource( qint64 uid, const QByteArray& remote_id,
+void Akonadi::DataStore::retrieveDataFromResource( qint64 uid, const QByteArray& remote_id, const QByteArray& mimeType,
                                                    const QString &resource, const QStringList &parts )
 {
   // TODO: error handling
@@ -664,9 +664,9 @@ void Akonadi::DataStore::retrieveDataFromResource( qint64 uid, const QByteArray&
       qDebug() << "requestItemDelivery(): requested parts:" << parts;
 
       // call the resource
-      org::kde::Akonadi::Resource *interface = resourceInterface( resource );
+      org::freedesktop::Akonadi::Resource *interface = resourceInterface( resource );
       if ( interface )
-        interface->requestItemDelivery( uid, QString::fromUtf8(remote_id), parts );
+        interface->requestItemDelivery( uid, QString::fromUtf8(remote_id), QString::fromUtf8(mimeType), parts );
 
       mPendingItemDeliveriesMutex.lock();
       qDebug() << "requestItemDelivery(): freeing uid" << uid;
@@ -678,7 +678,7 @@ void Akonadi::DataStore::retrieveDataFromResource( qint64 uid, const QByteArray&
 
 void DataStore::triggerCollectionSync( const Location &location )
 {
-  org::kde::Akonadi::Resource *interface = resourceInterface( location.resource().name() );
+  org::freedesktop::Akonadi::Resource *interface = resourceInterface( location.resource().name() );
   if ( interface )
     interface->synchronizeCollection( location.id() );
 }
@@ -895,17 +895,17 @@ bool Akonadi::DataStore::inTransaction() const
   return m_transactionLevel > 0;
 }
 
-org::kde::Akonadi::Resource * Akonadi::DataStore::resourceInterface( const QString &res )
+org::freedesktop::Akonadi::Resource * Akonadi::DataStore::resourceInterface( const QString &res )
 {
-  org::kde::Akonadi::Resource* iface = 0;
+  org::freedesktop::Akonadi::Resource* iface = 0;
   if ( mResourceInterfaceCache.contains( res ) )
     iface = mResourceInterfaceCache.value( res );
   if ( iface && iface->isValid() )
     return iface;
 
   delete iface;
-  iface = new org::kde::Akonadi::Resource( QLatin1String("org.kde.Akonadi.Resource.") + res,
-                                           QLatin1String("/"), QDBusConnection::sessionBus(), this );
+  iface = new org::freedesktop::Akonadi::Resource( QLatin1String("org.freedesktop.Akonadi.Resource.") + res,
+                                                   QLatin1String("/"), QDBusConnection::sessionBus(), this );
   if ( !iface || !iface->isValid() ) {
     qDebug() << QString::fromLatin1( "Cannot connect to agent instance with identifier '%1', error message: '%2'" )
                                     .arg( res, iface ? iface->lastError().message() : QString() );
